==> zio-aws-elasticsearch_2.13-6.20.120.1-sources.jar: zio/aws/elasticsearch/model/VpcEndpoint.scala <==
package zio.aws.elasticsearch.model
import zio.aws.elasticsearch.model.primitives.{
  Endpoint,
  DomainArn,
  AWSAccount,
  VpcEndpointId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class VpcEndpoint(
    vpcEndpointId: Optional[VpcEndpointId] = Optional.Absent,
    vpcEndpointOwner: Optional[AWSAccount] = Optional.Absent,
    domainArn: Optional[DomainArn] = Optional.Absent,
    vpcOptions: Optional[zio.aws.elasticsearch.model.VPCDerivedInfo] =
      Optional.Absent,
    status: Optional[zio.aws.elasticsearch.model.VpcEndpointStatus] =
      Optional.Absent,
    endpoint: Optional[Endpoint] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.VpcEndpoint = {
    import VpcEndpoint.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.VpcEndpoint
      .builder()
      .optionallyWith(
        vpcEndpointId.map(value =>
          VpcEndpointId.unwrap(value): java.lang.String
        )
      )(_.vpcEndpointId)
      .optionallyWith(
        vpcEndpointOwner.map(value =>
          AWSAccount.unwrap(value): java.lang.String
        )
      )(_.vpcEndpointOwner)
      .optionallyWith(
        domainArn.map(value => DomainArn.unwrap(value): java.lang.String)
      )(_.domainArn)
      .optionallyWith(vpcOptions.map(value => value.buildAwsValue()))(
        _.vpcOptions
      )
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(
        endpoint.map(value => Endpoint.unwrap(value): java.lang.String)
      )(_.endpoint)
      .build()
  }
  def asReadOnly: zio.aws.elasticsearch.model.VpcEndpoint.ReadOnly =
    zio.aws.elasticsearch.model.VpcEndpoint.wrap(buildAwsValue())
}
object VpcEndpoint {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.VpcEndpoint
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticsearch.model.VpcEndpoint =
      zio.aws.elasticsearch.model.VpcEndpoint(
        vpcEndpointId.map(value => value),
        vpcEndpointOwner.map(value => value),
        domainArn.map(value => value),
        vpcOptions.map(value => value.asEditable),
        status.map(value => value),
        endpoint.map(value => value)
      )
    def vpcEndpointId: Optional[VpcEndpointId]
    def vpcEndpointOwner: Optional[AWSAccount]
    def domainArn: Optional[DomainArn]
    def vpcOptions
        : Optional[zio.aws.elasticsearch.model.VPCDerivedInfo.ReadOnly]
    def status: Optional[zio.aws.elasticsearch.model.VpcEndpointStatus]
    def endpoint: Optional[Endpoint]
    def getVpcEndpointId: ZIO[Any, AwsError, VpcEndpointId] =
      AwsError.unwrapOptionField("vpcEndpointId", vpcEndpointId)
    def getVpcEndpointOwner: ZIO[Any, AwsError, AWSAccount] =
      AwsError.unwrapOptionField("vpcEndpointOwner", vpcEndpointOwner)
    def getDomainArn: ZIO[Any, AwsError, DomainArn] =
      AwsError.unwrapOptionField("domainArn", domainArn)
    def getVpcOptions: ZIO[
      Any,
      AwsError,
      zio.aws.elasticsearch.model.VPCDerivedInfo.ReadOnly
    ] = AwsError.unwrapOptionField("vpcOptions", vpcOptions)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.elasticsearch.model.VpcEndpointStatus] =
      AwsError.unwrapOptionField("status", status)
    def getEndpoint: ZIO[Any, AwsError, Endpoint] =
      AwsError.unwrapOptionField("endpoint", endpoint)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.VpcEndpoint
  ) extends zio.aws.elasticsearch.model.VpcEndpoint.ReadOnly {
    override val vpcEndpointId: Optional[VpcEndpointId] = zio.aws.core.internal
      .optionalFromNullable(impl.vpcEndpointId())
      .map(value => zio.aws.elasticsearch.model.primitives.VpcEndpointId(value))
    override val vpcEndpointOwner: Optional[AWSAccount] = zio.aws.core.internal
      .optionalFromNullable(impl.vpcEndpointOwner())
      .map(value => zio.aws.elasticsearch.model.primitives.AWSAccount(value))
    override val domainArn: Optional[DomainArn] = zio.aws.core.internal
      .optionalFromNullable(impl.domainArn())
      .map(value => zio.aws.elasticsearch.model.primitives.DomainArn(value))
    override val vpcOptions
        : Optional[zio.aws.elasticsearch.model.VPCDerivedInfo.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.vpcOptions())
        .map(value => zio.aws.elasticsearch.model.VPCDerivedInfo.wrap(value))
    override val status
        : Optional[zio.aws.elasticsearch.model.VpcEndpointStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.elasticsearch.model.VpcEndpointStatus.wrap(value))
    override val endpoint: Optional[Endpoint] = zio.aws.core.internal
      .optionalFromNullable(impl.endpoint())
      .map(value => zio.aws.elasticsearch.model.primitives.Endpoint(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.VpcEndpoint
  ): zio.aws.elasticsearch.model.VpcEndpoint.ReadOnly = new Wrapper(impl)
}

==> zio-aws-elasticsearch_3-7.30.30.1-sources.jar: zio/aws/elasticsearch/model/VpcEndpoint.scala <==
package zio.aws.elasticsearch.model
import zio.aws.elasticsearch.model.primitives.{
  Endpoint,
  DomainArn,
  AWSAccount,
  VpcEndpointId
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class VpcEndpoint(
    vpcEndpointId: Optional[VpcEndpointId] = Optional.Absent,
    vpcEndpointOwner: Optional[AWSAccount] = Optional.Absent,
    domainArn: Optional[DomainArn] = Optional.Absent,
    vpcOptions: Optional[zio.aws.elasticsearch.model.VPCDerivedInfo] =
      Optional.Absent,
    status: Optional[zio.aws.elasticsearch.model.VpcEndpointStatus] =
      Optional.Absent,
    endpoint: Optional[Endpoint] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.VpcEndpoint = {
    import VpcEndpoint.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.VpcEndpoint
      .builder()
      .optionallyWith(
        vpcEndpointId.map(value =>
          VpcEndpointId.unwrap(value): java.lang.String
        )
      )(_.vpcEndpointId)
      .optionallyWith(
        vpcEndpointOwner.map(value =>
          AWSAccount.unwrap(value): java.lang.String
        )
      )(_.vpcEndpointOwner)
      .optionallyWith(
        domainArn.map(value => DomainArn.unwrap(value): java.lang.String)
      )(_.domainArn)
      .optionallyWith(vpcOptions.map(value => value.buildAwsValue()))(
        _.vpcOptions
      )
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .optionallyWith(
        endpoint.map(value => Endpoint.unwrap(value): java.lang.String)
      )(_.endpoint)
      .build()
  }
  def asReadOnly: zio.aws.elasticsearch.model.VpcEndpoint.ReadOnly =
    zio.aws.elasticsearch.model.VpcEndpoint.wrap(buildAwsValue())
}
object VpcEndpoint {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.VpcEndpoint
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticsearch.model.VpcEndpoint =
      zio.aws.elasticsearch.model.VpcEndpoint(
        vpcEndpointId.map(value => value),
        vpcEndpointOwner.map(value => value),
        domainArn.map(value => value),
        vpcOptions.map(value => value.asEditable),
        status.map(value => value),
        endpoint.map(value => value)
      )
    def vpcEndpointId: Optional[VpcEndpointId]
    def vpcEndpointOwner: Optional[AWSAccount]
    def domainArn: Optional[DomainArn]
    def vpcOptions
        : Optional[zio.aws.elasticsearch.model.VPCDerivedInfo.ReadOnly]
    def status: Optional[zio.aws.elasticsearch.model.VpcEndpointStatus]
    def endpoint: Optional[Endpoint]
    def getVpcEndpointId: ZIO[Any, AwsError, VpcEndpointId] =
      AwsError.unwrapOptionField("vpcEndpointId", vpcEndpointId)
    def getVpcEndpointOwner: ZIO[Any, AwsError, AWSAccount] =
      AwsError.unwrapOptionField("vpcEndpointOwner", vpcEndpointOwner)
    def getDomainArn: ZIO[Any, AwsError, DomainArn] =
      AwsError.unwrapOptionField("domainArn", domainArn)
    def getVpcOptions: ZIO[
      Any,
      AwsError,
      zio.aws.elasticsearch.model.VPCDerivedInfo.ReadOnly
    ] = AwsError.unwrapOptionField("vpcOptions", vpcOptions)
    def getStatus
        : ZIO[Any, AwsError, zio.aws.elasticsearch.model.VpcEndpointStatus] =
      AwsError.unwrapOptionField("status", status)
    def getEndpoint: ZIO[Any, AwsError, Endpoint] =
      AwsError.unwrapOptionField("endpoint", endpoint)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.VpcEndpoint
  ) extends zio.aws.elasticsearch.model.VpcEndpoint.ReadOnly {
    override val vpcEndpointId: Optional[VpcEndpointId] = zio.aws.core.internal
      .optionalFromNullable(impl.vpcEndpointId())
      .map(value => zio.aws.elasticsearch.model.primitives.VpcEndpointId(value))
    override val vpcEndpointOwner: Optional[AWSAccount] = zio.aws.core.internal
      .optionalFromNullable(impl.vpcEndpointOwner())
      .map(value => zio.aws.elasticsearch.model.primitives.AWSAccount(value))
    override val domainArn: Optional[DomainArn] = zio.aws.core.internal
      .optionalFromNullable(impl.domainArn())
      .map(value => zio.aws.elasticsearch.model.primitives.DomainArn(value))
    override val vpcOptions
        : Optional[zio.aws.elasticsearch.model.VPCDerivedInfo.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.vpcOptions())
        .map(value => zio.aws.elasticsearch.model.VPCDerivedInfo.wrap(value))
    override val status
        : Optional[zio.aws.elasticsearch.model.VpcEndpointStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.elasticsearch.model.VpcEndpointStatus.wrap(value))
    override val endpoint: Optional[Endpoint] = zio.aws.core.internal
      .optionalFromNullable(impl.endpoint())
      .map(value => zio.aws.elasticsearch.model.primitives.Endpoint(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.VpcEndpoint
  ): zio.aws.elasticsearch.model.VpcEndpoint.ReadOnly = new Wrapper(impl)
}
